@@ -4,4 +4,4 @@ from pyqt_svg_abstractbutton import SvgAbstractButton
 
 class SvgButton(QPushButton, SvgAbstractButton):
     def __init__(self, base_widget: QWidget = None, *args, **kwargs):
-        super().__init__(*args, **kwargs)
\ No newline at end of file
+        super().__init__(base_widget, *args, **kwargs)
\ No newline at end of file
